==> usermin-1.840.tar.gz: usermin-1.840/mailbox/uconfig.info.cs <==
line0=Uživatelské rozhraní,11
perpage=Počet zpráv zobrazených na jedné stránce,0,5
top_buttons=Zobrazovat tlačítka v záhlaví,1,2-Složek i zpráv,1-Jen ve složkách,0-Nikde
arrows=Stránkovací šipky zobrazovat pro,1,2-Seznamy zpráv i jednotlivé zprávy,1-Jen v seznamech zpráv,0-Nikdy
show_to=Zobrazovat v seznamech zpráv adresu příjemce?,1,1-Ano,0-Ne
refresh=Interval automatického obnovení schránky,3,Neobnovovat
open_mode=Zprávy otevírat v,1,1-Novém okně,0-Okně seznamu
show_body=V seznamu ukazovat náhledy zpráv?,1,1-Ano,0-Ne
wrap_width=Šířka pro automatické odřádkování,0,5
auto_mark=Automaticky označovat zprávy jako přečtené?,1,1-Ano,0-Ne
view_html=Tělo zprávy zobrazovat jako,4,0-Vždy čistý text,1-Čistý text pokud to jde&#44; jinak HTML ,2-HTML pokud tom jde&#44; jinak text,3-Převádět HTML na čistý text
view_images=Zobrazit implicitně vložené obrázky?,1,0-Ano,1-Jako externí obrázky,2-Ne
head_html=Vložit HTML ze sekce &lt;head&gt; zprávy do stránky?,1,1-Ano,0-Ne
check_mod=Při mazání mailu kontrolovat modifikace schránky?,1,1-Ano,0-Ne
link_mode=Odkazy otevírat v,1,1-Novém okně,0-Původním okně
wrap_compose=Šířka pro zalamování napsaných poštovních zpráv,10,-Nezalamovat,80-80 sloupců (standardně),Jiná velikost
send_buttons=Zobrazit tlačítka pro odesílání zpráv,1,1-Nahoře i dole,0-Pouze dole
html_edit=Pro psaní zpráv používat HTML editor?,1,2-Vždy,1-Při odpovědi na maily v HTML,0-Nikdy
html_quote=Způsob označení citování v HTML,1,1-Zprávy pod &lt;hr&gt;,0-Zprávy uvnitř &lt;blockquote&gt;
spell_check=Povolit implicitně kontrolu pravopisu?,1,1-Ano,0-Ne
line1=Odesílání zpráv,11
no_mime=Posílat pokud možno zprávy pouze v textovém tvaru?,1,1-Ano,0-Ne
save_sent=Ukládat odesílané zprávy:,1,1-Ano,0-Ne
real_name=Vkládat skutečná jména do pole odesilatele?,1,1-Ano,0-Ne
charset=Znaková sada pro odeslání mailu
sig_file=Soubor s textovým podpisem,10,*-Žádný,.signature-~/.signature,Jiný soubor
fwd_mode=Uvozovat přeposílané zprávy?,1,0-Ano,1-Ne
from_in_to=Zobrazovat adresu odesilatele při výběru adresy příjemce?,1,1-Ano,0-Ne
sort_addrs=Adresář řadit podle,1,0-Pořadí vložení,1-Skutečného jména,2-Emailové adresy
reply_to=Adresa pro odpověď,10,x-Není,*-Zvolit při odesílání,Adresa..
bcc_to=Bcc: skryté kopie zpráv zasílat na,0
add_abook=Přidat příjemce do adresáře?,1,1-Ano,0-Ne
real_expand=Při odesílání hledat skutečná jména?,1,1-Ano,0-Ne
force_subject=Co dělat&#44; chybí&#45;li předmět zprávy,10,-Nic,error-Zobrazit chybu,Nastavit na
send_return=Po odeslání zobrazit,1,1-Seznam zpráv,0-Odeslanou zprávu
self_crypt=Zašifrovat zprávu rovněž Vaším neveřejným klíčem?,1,1-Ano,0-Ne
req_dsn=Požadovat potvrzení o přečtení?,1,1-Vždy,2-Volitelně,0-Nikdy
send_dsn=Odpověď na požadavek předání upozornění,1,1-Automaticky,2-Ručně,0-Nikdy
req_del=Požadovat potvrzení o doručení?,1,1-Vždy,2-Volitelně,0-Nikdy
date_fmt=Formát data v seznamu zpráv,1,dmy-DD/MM/YYYY,mdy-MM/DD/YYYY,ymd-YYYY/MM/DD
date_tz=časová zóna pro zobrazování časů,3,Výchozí systému
reply_date=Při citování emailu doplňovat datum?,1,1-Ano,0-Ne
line3=Složky zpráv,11
mailbox_recur=Podadresáře schránek chápat jako,1,1-Složky,0-Podadresáře
default_folder=Implicitní soubor složky,3,Přijatá
folder_sort=Způsob řazení složek,4,0-Vestavěné&#44; pak ~/mail&#44; nakonec externí,1-Vestavěné&#44; potom ostatní řazené podle jména,2-Seřadit všechny podle jmen
sent_name=Soubor pro složku odeslaných zpráv,3,Automaticky
drafts_name=Soubor pro složku s Koncepty,3,Automaticky
trash_name=Soubor pro složku koše,3,Automaticky
show_unread=Zobrazit počet nepřečtených zpráv,1,2-Ano,1-Pouze pro IMAP,0-No
related_search=Stejný předmět či odesilatele hledat,1,1-Ve všech složkách,2-V lokálních složkách,0-V aktuální složce
search_latest=Prohledávané zprávy,10,-Všechny zprávy,Jen posledních
mailbox_dir=Adresář se schránkami pod domovským adresářem,0,30
delete_warn=Potvrzovat mazání?,10,y-Ano,n-Ne,Pro soubory schránek větší než
delete_mode=Smazané zprávy,1,0-Prostě odstranit ze složky,1-Přesunout do koše
show_delall=Zobrazovat tlačítko pro smazání celé schránky?,1,1-Ano,0-Ne
line4=Volby pro Spam,11
spam_buttons=Tlačítka pro hlášení SPAMu zobrazovat,2,list-Seznamech zpráv,mail-Zprávách
ham_buttons=Tlačítka pro označení za platné (HAM) zobrazovat pro,2,list-Seznamy zpráv,mail-Zprávy
spam_del=Smazat SPAM po nahlášení?,1,1-Ano,0-Ne
white_move=Přesunout mail do Inboxu&#44; je&#45;li ve Whitelistu?,1,1-Ano,0-Ne
ham_move=Přesunout ham do Inboxu během oznámení?,1,1-Ano,0-Ne
white_book=Přidat všechny záznamy v Adresáři do Whitelistu?,1,1-Ano,0-Ne
white_rec=Přidat adresáty z odpovědí do Whitelistu?,1,1-Ano,0-Ne
line5=Volby pro přílohy,11
thumbnails=Zobrazit obrázky z příloh jako náhledy<br>(Vyžaduje knihovny příkazů <tt>cjpeg</tt>&#44; <tt>djpeg</tt> a PNM),1,1-Ano,0-Ne
def_attach=Výchozí počet nahraných příloh,0,8

==> usermin-2.510.tar.gz: usermin-2.510/mailbox/uconfig.info.cs <==
line0=Uživatelské rozhraní,11
perpage=Počet zpráv zobrazených na jedné stránce,0,5
top_buttons=Zobrazovat tlačítka v záhlaví,1,2-Složek i zpráv,1-Jen ve složkách,0-Nikde
arrows=Stránkovací šipky zobrazovat pro,1,2-Seznamy zpráv i jednotlivé zprávy,1-Jen v seznamech zpráv,0-Nikdy
show_to=Zobrazovat v seznamech zpráv adresu příjemce?,1,1-Ano,0-Ne
refresh=Interval automatického obnovení schránky,3,Neobnovovat
open_mode=Zprávy otevírat v,1,1-Novém okně,0-Okně seznamu
show_body=V seznamu ukazovat náhledy zpráv?,1,1-Ano,0-Ne
wrap_width=Šířka pro automatické odřádkování,0,5
auto_mark=Automaticky označovat zprávy jako přečtené?,1,1-Ano,0-Ne
view_html=Tělo zprávy zobrazovat jako,4,0-Vždy čistý text,1-Čistý text pokud to jde&#44; jinak HTML ,2-HTML pokud tom jde&#44; jinak text,3-Převádět HTML na čistý text
view_images=Zobrazit implicitně vložené obrázky?,1,0-Ano,1-Jako externí obrázky,2-Ne
check_mod=Při mazání mailu kontrolovat modifikace schránky?,1,1-Ano,0-Ne
link_mode=Odkazy otevírat v,1,1-Novém okně,0-Původním okně
wrap_compose=Šířka pro zalamování napsaných poštovních zpráv,10,-Nezalamovat,80-80 sloupců (standardně),Jiná velikost
send_buttons=Zobrazit tlačítka pro odesílání zpráv,1,1-Nahoře i dole,0-Pouze dole
html_edit=Pro psaní zpráv používat HTML editor?,1,2-Vždy,1-Při odpovědi na maily v HTML,0-Nikdy
html_quote=Způsob označení citování v HTML,1,1-Zprávy pod &lt;hr&gt;,0-Zprávy uvnitř &lt;blockquote&gt;
spell_check=Povolit implicitně kontrolu pravopisu?,1,1-Ano,0-Ne
line1=Odesílání zpráv,11
no_mime=Posílat pokud možno zprávy pouze v textovém tvaru?,1,1-Ano,0-Ne
save_sent=Ukládat odesílané zprávy:,1,1-Ano,0-Ne
real_name=Vkládat skutečná jména do pole odesilatele?,1,1-Ano,0-Ne
charset=Znaková sada pro odeslání mailu
sig_file=Soubor s textovým podpisem,10,*-Žádný,.signature-~/.signature,Jiný soubor
fwd_mode=Uvozovat přeposílané zprávy?,1,0-Ano,1-Ne
from_in_to=Zobrazovat adresu odesilatele při výběru adresy příjemce?,1,1-Ano,0-Ne
sort_addrs=Adresář řadit podle,1,0-Pořadí vložení,1-Skutečného jména,2-Emailové adresy
reply_to=Adresa pro odpověď,10,x-Není,*-Zvolit při odesílání,Adresa..
bcc_to=Bcc: skryté kopie zpráv zasílat na,0
add_abook=Přidat příjemce do adresáře?,1,1-Ano,0-Ne
real_expand=Při odesílání hledat skutečná jména?,1,1-Ano,0-Ne
force_subject=Co dělat&#44; chybí&#45;li předmět zprávy,10,-Nic,error-Zobrazit chybu,Nastavit na
send_return=Po odeslání zobrazit,1,1-Seznam zpráv,0-Odeslanou zprávu
self_crypt=Zašifrovat zprávu rovněž Vaším neveřejným klíčem?,1,1-Ano,0-Ne
req_dsn=Požadovat potvrzení o přečtení?,1,1-Vždy,2-Volitelně,0-Nikdy
send_dsn=Odpověď na požadavek předání upozornění,1,1-Automaticky,2-Ručně,0-Nikdy
req_del=Požadovat potvrzení o doručení?,1,1-Vždy,2-Volitelně,0-Nikdy
date_fmt=Formát data v seznamu zpráv,1,auto-Locale based,dmy-DD/MM/YYYY,mdy-MM/DD/YYYY,ymd-YYYY/MM/DD
date_tz=časová zóna pro zobrazování časů,3,Výchozí systému
reply_date=Při citování emailu doplňovat datum?,1,1-Ano,0-Ne
line3=Složky zpráv,11
mailbox_recur=Podadresáře schránek chápat jako,1,1-Složky,0-Podadresáře
default_folder=Implicitní soubor složky,3,Přijatá
folder_sort=Způsob řazení složek,4,0-Vestavěné&#44; pak ~/mail&#44; nakonec externí,1-Vestavěné&#44; potom ostatní řazené podle jména,2-Seřadit všechny podle jmen
sent_name=Soubor pro složku odeslaných zpráv,3,Automaticky
drafts_name=Soubor pro složku s Koncepty,3,Automaticky
trash_name=Soubor pro složku koše,3,Automaticky
show_unread=Zobrazit počet nepřečtených zpráv,1,2-Ano,1-Pouze pro IMAP,0-No
related_search=Stejný předmět či odesilatele hledat,1,1-Ve všech složkách,2-V lokálních složkách,0-V aktuální složce
search_latest=Prohledávané zprávy,10,-Všechny zprávy,Jen posledních
mailbox_dir=Adresář se schránkami pod domovským adresářem,0,30
delete_warn=Potvrzovat mazání?,10,y-Ano,n-Ne,Pro soubory schránek větší než
delete_mode=Smazané zprávy,1,0-Prostě odstranit ze složky,1-Přesunout do koše
show_delall=Zobrazovat tlačítko pro smazání celé schránky?,1,1-Ano,0-Ne
line4=Volby pro Spam,11
spam_buttons=Tlačítka pro hlášení SPAMu zobrazovat,2,list-Seznamech zpráv,mail-Zprávách
ham_buttons=Tlačítka pro označení za platné (HAM) zobrazovat pro,2,list-Seznamy zpráv,mail-Zprávy
spam_del=Smazat SPAM po nahlášení?,1,1-Ano,0-Ne
white_move=Přesunout mail do Inboxu&#44; je&#45;li ve Whitelistu?,1,1-Ano,0-Ne
ham_move=Přesunout ham do Inboxu během oznámení?,1,1-Ano,0-Ne
white_book=Přidat všechny záznamy v Adresáři do Whitelistu?,1,1-Ano,0-Ne
white_rec=Přidat adresáty z odpovědí do Whitelistu?,1,1-Ano,0-Ne
line5=Volby pro přílohy,11
thumbnails=Zobrazit obrázky z příloh jako náhledy<br>(Vyžaduje knihovny příkazů <tt>cjpeg</tt>&#44; <tt>djpeg</tt> a PNM),1,1-Ano,0-Ne
def_attach=Výchozí počet nahraných příloh,0,8
